From 930256f581b081d47492493fd1dd879be9500f20 Mon Sep 17 00:00:00 2001
From: Mike Salvatore <mike.s.salvatore@gmail.com>
Date: Tue, 20 Sep 2022 11:07:09 -0400
Subject: [PATCH] Agent: Take OperatingSystem in
 IIslandAPIClient.get_agent_binary()

---
 .../island_api_client/i_island_api_client.py                 | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/monkey/infection_monkey/island_api_client/i_island_api_client.py b/monkey/infection_monkey/island_api_client/i_island_api_client.py
index a15bfb671..5bebc79c1 100644
--- a/monkey/infection_monkey/island_api_client/i_island_api_client.py
+++ b/monkey/infection_monkey/island_api_client/i_island_api_client.py
@@ -1,6 +1,7 @@
 from abc import ABC, abstractmethod
 from typing import Optional, Sequence
 
+from common import OperatingSystem
 from common.agent_events import AbstractAgentEvent
 
 
@@ -59,11 +60,11 @@ class IIslandAPIClient(ABC):
         """
 
     @abstractmethod
-    def get_agent_binary(self, os_name: str) -> Optional[bytes]:
+    def get_agent_binary(self, operating_system: OperatingSystem) -> Optional[bytes]:
         """
         Get an agent binary for the given OS from the island
 
         :param os_name: The OS on which the agent binary will run
         :return: The agent binary file
         :raises IslandAPIConnectionError: If the client cannot successfully connect to the island
         :raises IslandAPIRequestError: If an error occurs while attempting to connect to the
@@ -59,11 +60,11 @@ class IIslandAPIClient(ABC):
         Get an agent binary for the given OS from the island
 
-        :param os_name: The OS on which the agent binary will run
+        :param operating_system: The OS on which the agent binary will run
         :return: The agent binary file
         :raises IslandAPIConnectionError: If the client cannot successfully connect to the island